==> qtjambi-uic-5.15.19-sources.jar: io/qt/uic/ui4/DomItem.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * @hidden
 * <p>Java wrapper for Qt class <code>DomItem</code></p>
 */
public class DomItem extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomItem::<wbr/>DomItem()</code></p>
     */
    public DomItem(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomItem instance);
    
    /**
     * <p>See <code>DomItem::<wbr/>attributeColumn()const</code></p>
     */
    @QtUninvokable
    public final int attributeColumn(){
        return attributeColumn_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int attributeColumn_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomItem::<wbr/>attributeRow()const</code></p>
     */
    @QtUninvokable
    public final int attributeRow(){
        return attributeRow_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int attributeRow_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomItem::<wbr/>clearAttributeColumn()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeColumn(){
        clearAttributeColumn_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeColumn_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomItem::<wbr/>clearAttributeRow()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeRow(){
        clearAttributeRow_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeRow_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomItem::<wbr/>elementItem()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QVector<io.qt.uic.ui4.@Nullable DomItem> elementItem(){
        return elementItem_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QVector<io.qt.uic.ui4.DomItem> elementItem_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomItem::<wbr/>elementProperty()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.uic.ui4.@Nullable DomProperty> elementProperty(){
        return elementProperty_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.uic.ui4.DomProperty> elementProperty_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomItem::<wbr/>hasAttributeColumn()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeColumn(){
        return hasAttributeColumn_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeColumn_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomItem::<wbr/>hasAttributeRow()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeRow(){
        return hasAttributeRow_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeRow_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomItem::<wbr/>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomItem::<wbr/>setAttributeColumn(int)</code></p>
     */
    @QtUninvokable
    public final void setAttributeColumn(int a){
        setAttributeColumn_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeColumn_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomItem::<wbr/>setAttributeRow(int)</code></p>
     */
    @QtUninvokable
    public final void setAttributeRow(int a){
        setAttributeRow_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeRow_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomItem::<wbr/>setElementItem(QVector&lt;DomItem*&gt;)</code></p>
     */
    @QtUninvokable
    public final void setElementItem(java.util.@NonNull Collection<? extends io.qt.uic.ui4.@Nullable DomItem> a){
        setElementItem_native_cref_QVector(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementItem_native_cref_QVector(long __this__nativeId, java.util.Collection<? extends io.qt.uic.ui4.DomItem> a);
    
    /**
     * <p>See <code>DomItem::<wbr/>setElementProperty(QList&lt;DomProperty*&gt;)</code></p>
     */
    @QtUninvokable
    public final void setElementProperty(java.util.@NonNull Collection<? extends io.qt.uic.ui4.@Nullable DomProperty> a){
        setElementProperty_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementProperty_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.uic.ui4.DomProperty> a);
    
    /**
     * <p>See <code>DomItem::<wbr/>write(QXmlStreamWriter&amp;,<wbr/>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomItem(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}

==> qtjambi-uic-6.2.10-sources.jar: io/qt/uic/ui4/DomItem.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomItem</p>
 */
public class DomItem extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomItem(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomItem instance);
    
    @io.qt.QtUninvokable
    public final int attributeColumn(){
        return attributeColumn_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int attributeColumn_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int attributeRow(){
        return attributeRow_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int attributeRow_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeColumn(){
        clearAttributeColumn_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeColumn_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeRow(){
        clearAttributeRow_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeRow_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.uic.ui4.DomItem> elementItem(){
        return elementItem_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.uic.ui4.DomItem> elementItem_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.uic.ui4.DomProperty> elementProperty(){
        return elementProperty_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.uic.ui4.DomProperty> elementProperty_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeColumn(){
        return hasAttributeColumn_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeColumn_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeRow(){
        return hasAttributeRow_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeRow_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setAttributeColumn(int a){
        setAttributeColumn_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeColumn_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setAttributeRow(int a){
        setAttributeRow_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeRow_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementItem(java.util.Collection<? extends io.qt.uic.ui4.DomItem> a){
        setElementItem_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementItem_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.uic.ui4.DomItem> a);
    
    @io.qt.QtUninvokable
    public final void setElementProperty(java.util.Collection<? extends io.qt.uic.ui4.DomProperty> a){
        setElementProperty_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementProperty_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.uic.ui4.DomProperty> a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomItem(QPrivateConstructor p) { super(p); } 
    
}
